==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGroupingDoneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupingDoneEventArgsDetailDescriptionMetadata } from "./WebGroupingDoneEventArgsDetailDescriptionMetadata";
import { WebGroupingDoneEventArgsDescription } from "./WebGroupingDoneEventArgsDescription";
/**
 * @hidden
 */
var WebGroupingDoneEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupingDoneEventArgsDescriptionMetadata, _super);
    function WebGroupingDoneEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupingDoneEventArgsDescriptionMetadata.b = function (a) {
        if (WebGroupingDoneEventArgsDescriptionMetadata.a == null) {
            WebGroupingDoneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupingDoneEventArgsDescriptionMetadata.c(WebGroupingDoneEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebGroupingDoneEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGroupingDoneEventArgsDescriptionMetadata.a);
        WebGroupingDoneEventArgsDetailDescriptionMetadata.d(a);
    };
    WebGroupingDoneEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupingDoneEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebGroupingDoneEventArgsDetail");
    };
    WebGroupingDoneEventArgsDescriptionMetadata.d = function (a) {
        WebGroupingDoneEventArgsDescriptionMetadata.b(a);
        a.aa("WebGroupingDoneEventArgs", function () { return new WebGroupingDoneEventArgsDescription(); });
        a.z("WebGroupingDoneEventArgs", WebGroupingDoneEventArgsDescriptionMetadata.a);
    };
    WebGroupingDoneEventArgsDescriptionMetadata.$t = markType(WebGroupingDoneEventArgsDescriptionMetadata, 'WebGroupingDoneEventArgsDescriptionMetadata');
    WebGroupingDoneEventArgsDescriptionMetadata.a = null;
    return WebGroupingDoneEventArgsDescriptionMetadata;
}(Base));
export { WebGroupingDoneEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGroupingDoneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupingDoneEventArgsDetailDescriptionMetadata } from "./WebGroupingDoneEventArgsDetailDescriptionMetadata";
import { WebGroupingDoneEventArgsDescription } from "./WebGroupingDoneEventArgsDescription";
/**
 * @hidden
 */
var WebGroupingDoneEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupingDoneEventArgsDescriptionMetadata, _super);
    function WebGroupingDoneEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupingDoneEventArgsDescriptionMetadata.b = function (a) {
        if (WebGroupingDoneEventArgsDescriptionMetadata.a == null) {
            WebGroupingDoneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupingDoneEventArgsDescriptionMetadata.c(WebGroupingDoneEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebGroupingDoneEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGroupingDoneEventArgsDescriptionMetadata.a);
        WebGroupingDoneEventArgsDetailDescriptionMetadata.d(a);
    };
    WebGroupingDoneEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupingDoneEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebGroupingDoneEventArgsDetail");
    };
    WebGroupingDoneEventArgsDescriptionMetadata.d = function (a) {
        WebGroupingDoneEventArgsDescriptionMetadata.b(a);
        a.ac("WebGroupingDoneEventArgs", function () { return new WebGroupingDoneEventArgsDescription(); });
        a.ab("WebGroupingDoneEventArgs", WebGroupingDoneEventArgsDescriptionMetadata.a);
    };
    WebGroupingDoneEventArgsDescriptionMetadata.$t = markType(WebGroupingDoneEventArgsDescriptionMetadata, 'WebGroupingDoneEventArgsDescriptionMetadata');
    WebGroupingDoneEventArgsDescriptionMetadata.a = null;
    return WebGroupingDoneEventArgsDescriptionMetadata;
}(Base));
export { WebGroupingDoneEventArgsDescriptionMetadata };
